==> huaweicloudsdkbssintl-3.1.126-py2.py3-none-any.whl: huaweicloudsdkbssintl/v2/model/list_renew_rate_on_period_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListRenewRateOnPeriodRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'body': 'ListRenewRateOnPeriodReq'
    }

    attribute_map = {
        'body': 'body'
    }

    def __init__(self, body=None):
        """ListRenewRateOnPeriodRequest

        The model defined in huaweicloud sdk

        :param body: Body of the ListRenewRateOnPeriodRequest
        :type body: :class:`huaweicloudsdkbssintl.v2.ListRenewRateOnPeriodReq`
        """
        
        

        self._body = None
        self.discriminator = None

        if body is not None:
            self.body = body

    @property
    def body(self):
        """Gets the body of this ListRenewRateOnPeriodRequest.

        :return: The body of this ListRenewRateOnPeriodRequest.
        :rtype: :class:`huaweicloudsdkbssintl.v2.ListRenewRateOnPeriodReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this ListRenewRateOnPeriodRequest.

        :param body: The body of this ListRenewRateOnPeriodRequest.
        :type body: :class:`huaweicloudsdkbssintl.v2.ListRenewRateOnPeriodReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListRenewRateOnPeriodRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkbssintl-3.1.158-py2.py3-none-any.whl: huaweicloudsdkbssintl/v2/model/list_renew_rate_on_period_request.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class ListRenewRateOnPeriodRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'body': 'ListRenewRateOnPeriodReq'
    }

    attribute_map = {
        'body': 'body'
    }

    def __init__(self, body=None):
        r"""ListRenewRateOnPeriodRequest

        The model defined in huaweicloud sdk

        :param body: Body of the ListRenewRateOnPeriodRequest
        :type body: :class:`huaweicloudsdkbssintl.v2.ListRenewRateOnPeriodReq`
        """
        
        

        self._body = None
        self.discriminator = None

        if body is not None:
            self.body = body

    @property
    def body(self):
        r"""Gets the body of this ListRenewRateOnPeriodRequest.

        :return: The body of this ListRenewRateOnPeriodRequest.
        :rtype: :class:`huaweicloudsdkbssintl.v2.ListRenewRateOnPeriodReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        r"""Sets the body of this ListRenewRateOnPeriodRequest.

        :param body: The body of this ListRenewRateOnPeriodRequest.
        :type body: :class:`huaweicloudsdkbssintl.v2.ListRenewRateOnPeriodReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ListRenewRateOnPeriodRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
